pynssp.detectors package
========================

Submodules
----------

pynssp.detectors.ewma module
----------------------------

.. automodule:: pynssp.detectors.ewma
   :members:
   :undoc-members:
   :show-inheritance:

pynssp.detectors.nbinom module
------------------------------

.. automodule:: pynssp.detectors.nbinom
   :members:
   :undoc-members:
   :show-inheritance:

pynssp.detectors.regression module
----------------------------------

.. automodule:: pynssp.detectors.regression
   :members:
   :undoc-members:
   :show-inheritance:

pynssp.detectors.serfling module
--------------------------------

.. automodule:: pynssp.detectors.serfling
   :members:
   :undoc-members:
   :show-inheritance:

pynssp.detectors.switch module
------------------------------

.. automodule:: pynssp.detectors.switch
   :members:
   :undoc-members:
   :show-inheritance:

pynssp.detectors.trend module
-----------------------------

.. automodule:: pynssp.detectors.trend
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pynssp.detectors
   :members:
   :undoc-members:
   :show-inheritance:
